@@ -142,7 +142,7 @@ class AnchorImageSampler:
             covered_false = [scale_image(img) for img in covered_false]
             # coverage set to -1.0 as we can't compute 'true' coverage for this model
 
-            return [covered_true, covered_false, labels.astype(int), data, -1.0, anchor[0]]  # type: ignore
+            return [covered_true, covered_false, labels.astype(int), data, -1.0, anchor[0]]
 
         else:
             data = self._choose_superpixels(num_samples)
