@@ -475,12 +475,12 @@ def update_actor_critic(encoder: nn.Module,
 
     # Define state by concatenating the input embedding, the classification label, the target label, and optionally
     # the conditional vector if exists.
-    state = [Z, Y_m, Y_t] + ([C] if (C is not None) else [])  # type: ignore
+    state = [Z, Y_m, Y_t] + ([C] if (C is not None) else [])
     state = torch.cat(state, dim=1).to(device)  # type: ignore
 
     # Define input for critic, compute q-values and append critic's loss.
     input_critic = torch.cat([state, Z_cf_tilde], dim=1).float()  # type: ignore
-    output_critic = critic(input_critic).squeeze(1)  # type: ignore
+    output_critic = critic(input_critic).squeeze(1)
     loss_critic = F.mse_loss(output_critic, R_tilde)  # type: ignore
     losses.update({"critic_loss": loss_critic.item()})
 
