@@ -2,6 +2,7 @@ import copy
 import logging
 import string
 import warnings
+from enum import Enum
 from typing import Callable, List, Optional, Tuple, Union, cast
 
 import numpy as np
@@ -779,11 +780,22 @@ def _validate_output(model: tf.keras.Model,
                        "Targets can be either the true classes or the classes predicted by the model.")
 
 
+class LayerState(str, Enum):
+    UNSPECIFIED = 'unspecified'
+    NON_SERIALIZABLE = 'non-serializable'
+    CALLABLE = 'callable'
+
+
 class IntegratedGradients(Explainer):
 
     def __init__(self,
                  model: tf.keras.Model,
-                 layer: Optional[tf.keras.layers.Layer] = None,
+                 layer: Optional[
+                     Union[
+                         Callable[[tf.keras.Model], tf.keras.layers.Layer],
+                         tf.keras.layers.Layer
+                     ]
+                 ] = None,
                  target_fn: Optional[Callable] = None,
                  method: str = "gausslegendre",
                  n_steps: int = 50,
@@ -799,8 +811,10 @@ class IntegratedGradients(Explainer):
         model
             `tensorflow` model.
         layer
-            Layer with respect to which the gradients are calculated.
-            If not provided, the gradients are calculated with respect to the input.
+            A layer or a function having as parameter the model and returning a layer with respect to which the
+            gradients are calculated. If not provided, the gradients are calculated with respect to the input.
+            To guarantee saving and loading of the explainer, the layer has to be specified as a callable which
+            returns a layer given the model. E.g. ``lambda model: model.layers[0].embeddings``.
         target_fn
             A scalar function that is applied to the predictions of the model.
             This can be used to specify which scalar output the attributions should be calculated for.
@@ -829,18 +843,33 @@ class IntegratedGradients(Explainer):
 
         if layer is None:
             self.orig_call: Optional[Callable] = None
-            layer_num: Optional[int] = 0
-        else:
-            self.orig_call = layer.call
-            try:
-                layer_num = model.layers.index(layer)
-            except ValueError:
-                logger.info("Layer not in the list of model.layers")
-                layer_num = None
+            self.layer = None
+            layer_meta: Union[int, str] = LayerState.UNSPECIFIED.value
 
-        params['layer'] = layer_num
+        elif isinstance(layer, tf.keras.layers.Layer):
+            self.orig_call = layer.call
+            self.layer = layer
+
+            try:
+                layer_meta = model.layers.index(layer)
+            except ValueError:
+                layer_meta = LayerState.NON_SERIALIZABLE.value
+                logger.warning('Layer not in the list of `model.layers`. Passing the layer directly would not '
+                               'permit the serialization of the explainer. This is due to nested layers. To permit '
+                               'the serialization of the explainer, provide the layer as a callable which returns '
+                               'the layer given the model.')
+
+        elif callable(layer):
+            self.layer = layer(self.model)
+            self.orig_call = self.layer.call
+            self.callable_layer = layer
+            layer_meta = LayerState.CALLABLE.value
+
+        else:
+            raise TypeError(f'Unsupported layer type. Received {type(layer)}.')
+
+        params['layer'] = layer_meta
         self.meta['params'].update(params)
-        self.layer = layer
         self.n_steps = n_steps
         self.method = method
         self.internal_batch_size = internal_batch_size
@@ -912,7 +941,7 @@ class IntegratedGradients(Explainer):
 
         if self._is_list:
             X = cast(List[np.ndarray], X)  # help mypy out
-            self.orig_dummy_input = [np.zeros((1,) + xx.shape[1:], dtype=xx.dtype) for xx in X]  # type: ignore
+            self.orig_dummy_input = [np.zeros((1,) + xx.shape[1:], dtype=xx.dtype) for xx in X]
             nb_samples = len(X[0])
             input_dtypes = [xx.dtype for xx in X]
             # Formatting baselines in case of models with multiple inputs
@@ -938,9 +967,9 @@ class IntegratedGradients(Explainer):
 
         elif self._is_np:
             X = cast(np.ndarray, X)  # help mypy out
-            self.orig_dummy_input = np.zeros((1,) + X.shape[1:], dtype=X.dtype)  # type: ignore
+            self.orig_dummy_input = np.zeros((1,) + X.shape[1:], dtype=X.dtype)
             nb_samples = len(X)
-            input_dtypes = [X.dtype]  # type: ignore
+            input_dtypes = [X.dtype]
             # Formatting baselines for models with a single input
             baselines = _format_baseline(X, baselines)  # type: ignore # TODO: validate/narrow baselines type
 
@@ -950,7 +979,7 @@ class IntegratedGradients(Explainer):
         # defining integral method
         step_sizes_func, alphas_func = approximation_parameters(self.method)
         step_sizes, alphas = step_sizes_func(self.n_steps), alphas_func(self.n_steps)
-        target = _format_target(target, nb_samples)  # type: ignore[assignment]
+        target = _format_target(target, nb_samples)
 
         if self._is_list:
             X = cast(List[np.ndarray], X)  # help mypy out
@@ -961,7 +990,7 @@ class IntegratedGradients(Explainer):
                 inputs = [tf.keras.Input(shape=xx.shape[1:], dtype=xx.dtype) for xx in X]
                 self.model(inputs, **forward_kwargs)
 
-            _validate_output(self.model, target)  # type: ignore[arg-type]
+            _validate_output(self.model, target)
             _check_target(self.model.output_shape, target, nb_samples)
             if self.layer is None:
                 # No layer passed, attributions computed with respect to the inputs
@@ -1147,7 +1176,7 @@ class IntegratedGradients(Explainer):
         # define paths in features' space
         paths = []
         for i in range(len(X)):
-            x, baseline = X[i], baselines[i]  # type: ignore
+            x, baseline = X[i], baselines[i]
             # construct paths
             path = np.concatenate([baseline + alphas[i] * (x - baseline) for i in range(self.n_steps)], axis=0)
             paths.append(path)
@@ -1223,7 +1252,7 @@ class IntegratedGradients(Explainer):
                                          target, target_paths,
                                          self.n_steps, nb_samples,
                                          step_sizes, j)
-            norm = X[j] - baselines[j]  # type: ignore
+            norm = X[j] - baselines[j]
             attribution = norm * sum_int
             attributions.append(attribution)
 
