@@ -1,14 +1,16 @@
-from typing import Union, Type
+from typing import Type, Union
 
-from alibi.utils.frameworks import has_pytorch, has_tensorflow, Framework
+from alibi.utils.frameworks import Framework, has_pytorch, has_tensorflow
 
 if has_pytorch:
     # import pytorch backend
-    from alibi.explainers.similarity.backends.pytorch.base import _PytorchBackend
+    from alibi.explainers.similarity.backends.pytorch.base import \
+        _PytorchBackend
 
 if has_tensorflow:
     # import tensorflow backend
-    from alibi.explainers.similarity.backends.tensorflow.base import _TensorFlowBackend
+    from alibi.explainers.similarity.backends.tensorflow.base import \
+        _TensorFlowBackend
 
 
 def _select_backend(backend: Framework = Framework.TENSORFLOW) \
