@@ -2,6 +2,7 @@ import re
 import sys
 from copy import deepcopy
 from typing import Dict, List, Optional, Tuple, Union
+from packaging import version
 
 import matplotlib.pyplot as plt
 import numpy as np
@@ -17,6 +18,7 @@ from sklearn.model_selection import train_test_split
 from sklearn.multioutput import MultiOutputClassifier
 from sklearn.pipeline import Pipeline
 from sklearn.utils import Bunch, shuffle
+import sklearn
 
 from alibi.api.defaults import DEFAULT_DATA_PD, DEFAULT_META_PD
 from alibi.api.interfaces import Explanation
@@ -387,19 +389,28 @@ def test_sklearn_numerical(rf_classifier, iris_data, features, params):
 @pytest.mark.parametrize('params', [
     {
         'percentiles': (0, 1),
-        'grid_resolution': np.inf,
         'method': 'brute',
         'kind': 'average'
     }
 ])
 def test_sklearn_categorical(rf_classifier, adult_data, features, params):
     """ Checks `alibi` pd black-box implementation against the `sklearn` implementation for categorical features."""
+
     rf, preprocessor = rf_classifier
     rf_pipeline = Pipeline(steps=[('preprocessor', preprocessor), ('predictor', rf)])
 
     # subsample data for faster computation
     X_train = adult_data['X_train'][:100]
 
+    # Behaviour depends on sklearn version, See https://github.com/SeldonIO/alibi/pull/940#issuecomment-1623783025
+    sklearn_version = version.parse(sklearn.__version__)
+    if sklearn_version >= version.parse('1.3.0'):
+        categorical_names = adult_data['metadata']['category_map']
+        categorical_names = list(categorical_names.keys())
+        params.update(categorical_features=categorical_names)
+    else:
+        params.update(grid_resolution=np.inf)
+
     # compute `sklearn` explanation
     exp_sklearn = partial_dependence(X=X_train,
                                      estimator=rf_pipeline,
@@ -432,7 +443,7 @@ def test_sklearn_categorical(rf_classifier, adult_data, features, params):
 @pytest.mark.parametrize('params', [
     {
         'percentiles': (0, 1),
-        'grid_resolution': np.inf,
+        'grid_resolution': 30,
         'method': 'recursion',
         'kind': 'average'
     }
@@ -606,7 +617,7 @@ def assert_deciles(xsegments: Optional[List[np.ndarray]] = None,
 
 def assert_pd_values(feature_values: np.ndarray, pd_values: np.ndarray, line: plt.Line2D):
     """ Checks if the plotted pd values are correct. """
-    x, y = line.get_xydata().T
+    x, y = line.get_xydata().T  # type: ignore[union-attr]
     assert np.allclose(x, feature_values)
     assert np.allclose(y, pd_values)
 
@@ -614,7 +625,7 @@ def assert_pd_values(feature_values: np.ndarray, pd_values: np.ndarray, line: pl
 def assert_ice_values(feature_values: np.ndarray, ice_values: np.ndarray, lines: List[plt.Line2D]):
     """ Checks if the plotted ice values are correct. """
     for ice_vals, line in zip(ice_values, lines):
-        x, y = line.get_xydata().T
+        x, y = line.get_xydata().T  # type: ignore[union-attr]
         assert np.allclose(x, feature_values)
         assert np.allclose(y, ice_vals)
 
@@ -633,7 +644,7 @@ def assert_pd_ice_values(feature: int, target_idx: int, kind: str, explanation:
         lines = ax.lines if kind == 'individual' else ax.lines[:2]
         assert_ice_values(feature_values=explanation.data['feature_values'][feature],
                           ice_values=explanation.data['ice_values'][feature][target_idx],
-                          lines=lines)
+                          lines=lines)  # type: ignore[arg-type]
 
 
 @pytest.mark.parametrize('explanation', ['average', 'individual', 'both'], indirect=True)
